=========
circuitry
=========

Embedded domain-specific combinator library for assembling abstract definitions of logic circuits.

Purpose
-------
This embedded domain-specific language (DSL) makes it possible to write an algorithm in Python that operates over bit vectors, and then to interpret that algorithm implementation as a circuit definition.
